Base — skchange

Skip to main content
`Ctrl`+`K`

# Base

The `skchange.base` module contains the abstract detector class `skchange.base.BaseDetector`. This class serves as a minimalistic template for all the detectors in `skchange`.

For common detection tasks, like changepoint detection or anomaly detection, there are dedicated subclasses of `BaseDetector` that implement a stricter template for these tasks. These subclasses are located in the respective modules, e.g. `skchange.change_detectors.base` or `skchange.anomaly_detectors.base`.

## Base classes

`BaseDetector`() | Base class for all detectors in skchange.